@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2009 Maxime DOYEN
+ *  Copyright (C) 1995-2010 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -109,6 +109,7 @@ Archive *item;
 
 	item = da_archive_malloc();
 	item->wording = g_strdup_printf(_("(archive %d)"), g_list_length(GLOBALS->arc_list) + 1);
+	item->unit = 2;
 
 	GLOBALS->arc_list = g_list_append(GLOBALS->arc_list, item);
 
@@ -307,8 +308,8 @@ Archive *item;
 		if(bool == 1) item->flags |= OF_REMIND;
 
 		item->paymode		= gtk_combo_box_get_active(GTK_COMBO_BOX(data->NU_mode));
-		item->category		= ui_cat_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_grp));
-		item->payee			= ui_pay_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_pay));
+		item->category		= ui_cat_comboboxentry_get_key_add_new(GTK_COMBO_BOX_ENTRY(data->PO_grp));
+		item->payee			= ui_pay_comboboxentry_get_key_add_new(GTK_COMBO_BOX_ENTRY(data->PO_pay));
 		item->account		= ui_acc_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_acc));
 		item->dst_account	= ui_acc_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_accto));
 
@@ -592,6 +593,7 @@ gint i;
 	ui_acc_comboboxentry_populate(GTK_COMBO_BOX_ENTRY(data->PO_acc)  , GLOBALS->h_acc);
 	ui_acc_comboboxentry_populate(GTK_COMBO_BOX_ENTRY(data->PO_accto), GLOBALS->h_acc);
 
+	
 }
 
 
@@ -680,14 +682,6 @@ gint row;
 	gtk_misc_set_padding (GTK_MISC (label), HB_BOX_SPACING, 0);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
-	label = gtk_label_new_with_mnemonic (_("_Wording:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	widget = make_string(label);
-	data.ST_word = widget;
-	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-
-	row++;
 	label = gtk_label_new_with_mnemonic (_("_Amount:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
@@ -703,30 +697,23 @@ gint row;
 
 	gtk_table_attach (GTK_TABLE (table), hbox, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
+
 	row++;
-	label = gtk_label_new_with_mnemonic (_("A_ccount:"));
+	label = gtk_label_new_with_mnemonic (_("_Payee:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	widget = ui_acc_comboboxentry_new(label);	
-	data.PO_acc = widget;
+	widget = ui_pay_comboboxentry_new(label);	
+	data.PO_pay = widget;
 	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
 	row++;
-	widget = gtk_check_button_new_with_mnemonic (_("_Validated"));
-	data.CM_valid = widget;
-	gtk_table_attach (GTK_TABLE (table), widget, 1, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	label = gtk_label_new_with_mnemonic (_("_Category:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	widget = ui_cat_comboboxentry_new(label);
+	data.PO_grp = widget;
+	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
-	row++;
-	widget = gtk_check_button_new_with_mnemonic (_("_Remind"));
-	data.CM_remind = widget;
-	gtk_table_attach (GTK_TABLE (table), widget, 1, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-
-	//**
-
-	row++;
-	label = make_label(NULL, 0.0, 0.0);
-	gtk_label_set_markup (GTK_LABEL(label), _("<b>Optional infos</b>"));
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 3, row, row+1);
 
 	row++;
 	label = gtk_label_new_with_mnemonic (_("Pay_ment:"));
@@ -760,21 +747,40 @@ gint row;
 		data.PO_accto = widget;
 		gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
+
+	//**
+
 	row++;
-	label = gtk_label_new_with_mnemonic (_("_Payee:"));
+	label = make_label(NULL, 0.0, 0.0);
+	gtk_label_set_markup (GTK_LABEL(label), _("<b>Optional infos</b>"));
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 3, row, row+1);
+
+	row++;
+	label = gtk_label_new_with_mnemonic (_("_Description:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	widget = ui_pay_comboboxentry_new(label);	
-	data.PO_pay = widget;
+	widget = make_string(label);
+	data.ST_word = widget;
+	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	
+	row++;
+	label = gtk_label_new_with_mnemonic (_("A_ccount:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	widget = ui_acc_comboboxentry_new(label);	
+	data.PO_acc = widget;
 	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
 	row++;
-	label = gtk_label_new_with_mnemonic (_("_Category:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	widget = ui_cat_comboboxentry_new(label);
-	data.PO_grp = widget;
-	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	widget = gtk_check_button_new_with_mnemonic (_("_Validated"));
+	data.CM_valid = widget;
+	gtk_table_attach (GTK_TABLE (table), widget, 1, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+
+	row++;
+	widget = gtk_check_button_new_with_mnemonic (_("_Remind"));
+	data.CM_remind = widget;
+	gtk_table_attach (GTK_TABLE (table), widget, 1, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+
 
 
 	// ----
@@ -828,6 +834,9 @@ gint row;
 	data.PO_next = widget;
 	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
+	/* set default periodicity to month */
+	//todo: ove elsewhere
+	gtk_combo_box_set_active(GTK_COMBO_BOX(data.CY_unit), 2);
 
 
 
