@@ -23,6 +23,7 @@
 #include "ui_category.h"
 #include "def_budget.h"
 #include "ui_category.h"
+#include "import.h"
 
 /****************************************************************************/
 /* Debug macros                                                             */
@@ -213,6 +214,8 @@ static void defbudget_load_csv( GtkWidget *widget, gpointer user_data)
 struct defbudget_data *data;
 gchar *filename = NULL;
 GIOChannel *io;
+const gchar *encoding;
+
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(widget), GTK_TYPE_WINDOW)), "inst_data");
 
@@ -223,6 +226,8 @@ GIOChannel *io;
 	{
 		DB( g_print(" + filename is %s\n", filename) );
 
+		encoding = homebank_file_getencoding(filename);
+
 		io = g_io_channel_new_file(filename, "r", NULL);
 		if(io != NULL)
 		{
@@ -232,6 +237,12 @@ GIOChannel *io;
 		gchar *tmpstr;
 		gint io_stat;
 
+			DB( g_print(" -> encoding should be %s\n", encoding) );
+			if( encoding != NULL )
+			{
+				g_io_channel_set_encoding(io, encoding, NULL);
+			}
+			
 			model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_cat));
 
 			for(;;)
