@@ -771,6 +771,7 @@ gint *indices;
 	}
 
 	/* deal with transfer to be validated also */
+	/* #492755
 	if( entry->paymode == PAYMODE_INTXFER )
 	{
 	Operation *ct;
@@ -781,7 +782,7 @@ gint *indices;
 			ct->flags ^= OF_VALID;
 			ct->flags |= OF_CHANGED;
 		}
-	}
+	}*/
 
 
 }
@@ -2008,7 +2009,7 @@ GError *error = NULL;
 	//gtk_container_set_border_width (GTK_CONTAINER(sw), HB_BOX_SPACING);
 
 	// create tree view
-	treeview = (GtkWidget *)create_list_operation(PREFS->lst_ope_columns);
+	treeview = (GtkWidget *)create_list_operation(TRN_LIST_TYPE_BOOK, PREFS->lst_ope_columns);
 	data->LV_ope = treeview;
 	gtk_container_add (GTK_CONTAINER (sw), treeview);
 
