@@ -29,6 +29,7 @@
 #include "ui_payee.h"
 #include "ui_category.h"
 #include "ui_assign.h"
+#include "ui-assist-start.h"
 #include "def_archive.h"
 #include "def_budget.h"
 #include "def_pref.h"
@@ -36,6 +37,7 @@
 #include "hb_transaction.h"
 
 
+
 #include "list_account.h"
 #include "list_upcoming.h"
 
@@ -114,6 +116,7 @@ static void wallet_action_import(void);
 static void wallet_action_export(void);
 
 static void wallet_action_help(void);
+void wallet_action_help_welcome(void);
 static void wallet_action_help_online(void);
 static void wallet_action_help_translate(void);
 static void wallet_action_help_problem(void);
@@ -202,13 +205,14 @@ static GtkActionEntry entries[] = {
   { "Carcost"    , HB_STOCK_REP_CAR   , N_("_Car cost...")   , NULL,    N_("Open the Car cost report"),    G_CALLBACK (wallet_action_carcost) },
 
   /* ToolsMenu */
-  { "ImportAmiga", NULL                     , N_("Import Amiga..."), NULL, N_("Import a file in Amiga 3.0 format"),    G_CALLBACK (wallet_action_importamiga) },
+  { "ImportAmiga", NULL               , N_("Import Amiga..."), NULL, N_("Import a file in Amiga 3.0 format"),    G_CALLBACK (wallet_action_importamiga) },
 
   /* HelpMenu */
-  { "Contents"   , GTK_STOCK_HELP       , N_("_Contents")  , "F1", N_("Documentation about HomeBank"), G_CALLBACK (wallet_action_help) },
-  { "Online"     , "lpi-help"        , N_("Get Help Online...")  , NULL, N_("Connect to the LaunchPad website for online help"), G_CALLBACK (wallet_action_help_online) },
-  { "Translate"  , "lpi-translate"   , N_("Translate this Application...")  , NULL, N_("Connect to the LaunchPad website to help translate this application"), G_CALLBACK (wallet_action_help_translate) },
-  { "Problem"    , "lpi-bug"         , N_("Report a Problem...")  , NULL, N_("Connect to the LaunchPad website to help fix problems"), G_CALLBACK (wallet_action_help_problem) },
+  { "Contents"   , GTK_STOCK_HELP    , N_("_Contents")                    , "F1", N_("Documentation about HomeBank"), G_CALLBACK (wallet_action_help) },
+  { "Welcome"    , NULL              , N_("Show welcome dialog...")       , NULL, NULL                              , G_CALLBACK (wallet_action_help_welcome) },
+  { "Online"     , "lpi-help"        , N_("Get Help Online...")           , NULL, N_("Connect to the LaunchPad website for online help"), G_CALLBACK (wallet_action_help_online) },
+  { "Translate"  , "lpi-translate"   , N_("Translate this Application..."), NULL, N_("Connect to the LaunchPad website to help translate this application"), G_CALLBACK (wallet_action_help_translate) },
+  { "Problem"    , "lpi-bug"         , N_("Report a Problem...")          , NULL, N_("Connect to the LaunchPad website to help fix problems"), G_CALLBACK (wallet_action_help_problem) },
 
   { "About"      , GTK_STOCK_ABOUT      , N_("_About")     , NULL, N_("About HomeBank")      ,G_CALLBACK (wallet_about) },
 
@@ -301,6 +305,8 @@ static const gchar *ui_info =
 "    <menu action='HelpMenu'>"
 "      <menuitem action='Contents'/>"
 "      <separator/>"
+"      <menuitem action='Welcome'/>"
+"      <separator/>"
 "      <menuitem action='Online'/>"
 "      <menuitem action='Translate'/>"
 "      <menuitem action='Problem'/>"
@@ -622,6 +628,101 @@ gboolean retval;
 
 }
 
+static void
+wallet_action_help_welcome1 (GtkButton *button, gpointer user_data)
+{
+	gtk_dialog_response (GTK_DIALOG(user_data), 1);
+}
+
+static void
+wallet_action_help_welcome2 (GtkButton *button, gpointer user_data)
+{
+	gtk_dialog_response (GTK_DIALOG(user_data), 2);
+}
+
+static void
+wallet_action_help_welcome3 (GtkButton *button, gpointer user_data)
+{
+	gtk_dialog_response (GTK_DIALOG(user_data), 3);
+}
+
+void wallet_action_help_welcome(void)
+{
+GtkWidget *dialog;
+GtkWidget *mainvbox, *widget, *label;
+	
+	dialog = gtk_dialog_new_with_buttons (_("Welcome to HomeBank"),
+			GTK_WINDOW(GLOBALS->mainwindow),
+			0,
+			GTK_STOCK_CLOSE,
+			GTK_RESPONSE_ACCEPT,
+			NULL);
+
+	mainvbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), mainvbox, FALSE, FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER(mainvbox), HB_MAINBOX_SPACING);
+
+	label = make_label (_("HomeBank"), 0, 0);
+	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
+	gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, 0);
+
+	label = make_label (_("Free, easy, personal accounting for everyone."), 0, 0);
+	gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, 0);
+
+		widget = gtk_hseparator_new();
+		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), widget, FALSE, FALSE, 0);
+
+	mainvbox = gtk_vbox_new (FALSE, HB_MAINBOX_SPACING);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), mainvbox, TRUE, TRUE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER(mainvbox), HB_MAINBOX_SPACING);
+
+	label = make_label (_("What do you want to do:"), 0, 0);
+	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
+	gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, 0);
+
+	widget = gtk_button_new_with_mnemonic(_("Create a _new wallet"));
+	gtk_box_pack_start (GTK_BOX (mainvbox), widget, FALSE, FALSE, 0);
+	g_signal_connect (widget, "clicked", G_CALLBACK (wallet_action_help_welcome1), dialog); 
+	
+	widget = gtk_button_new_with_mnemonic(_("_Open an existing wallet"));
+	gtk_box_pack_start (GTK_BOX (mainvbox), widget, FALSE, FALSE, 0);
+	g_signal_connect (widget, "clicked", G_CALLBACK (wallet_action_help_welcome2), dialog); 
+	
+	widget = gtk_button_new_with_mnemonic(_("Open the _example file"));
+	gtk_box_pack_start (GTK_BOX (mainvbox), widget, FALSE, FALSE, 0);
+	g_signal_connect (widget, "clicked", G_CALLBACK (wallet_action_help_welcome3), dialog); 
+	
+	//connect all our signals
+	g_signal_connect (dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &dialog);
+
+	gtk_widget_show_all (dialog);
+
+	//wait for the user
+	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	// cleanup and destroy
+	gtk_widget_destroy (dialog);
+
+	// do appropriate action
+	switch(result)
+	{
+		case 1:
+			wallet_action_new();
+			break;
+		case 2:
+			wallet_action_open();
+			break;
+		case 3:
+			g_free(GLOBALS->filename);
+			GLOBALS->filename = g_build_filename(homebank_app_get_datas_dir(), "example.xhb", NULL);
+			wallet_open_internal(GLOBALS->mainwindow, NULL);
+			break;
+	}
+
+}
+
+
+
 static void wallet_action_help_online(void)
 {
 gboolean retval;
@@ -787,6 +888,30 @@ static void wallet_selection(GtkTreeSelection *treeselection, gpointer user_data
 	wallet_update(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), GINT_TO_POINTER(UF_SENSITIVE));
 }
 
+
+static void wallet_close_openbooks(void)
+{
+GList *list;
+	
+	DB( g_printf("(wallet) close openbooks\n") );
+
+	list = g_hash_table_get_values(GLOBALS->h_acc);
+	while (list != NULL)
+	{
+	Account *item = list->data;
+
+		if(item->window)
+			gtk_widget_destroy(GTK_WIDGET(item->window));
+
+			
+		list = g_list_next(list);
+	}
+	g_list_free(list);
+
+}
+
+
+
 /*
 **
 */
@@ -841,6 +966,10 @@ gboolean file_clear = GPOINTER_TO_INT(user_data);
 	data->today = 0;
 	data->future = 0;
 
+	/* close any open accoutn window */
+	wallet_close_openbooks();
+
+	
 	// clear Lists
 	DB( g_printf(" -> h_acc\n") );
 	da_acc_destroy();
@@ -878,6 +1007,12 @@ gboolean file_clear = GPOINTER_TO_INT(user_data);
 
 	GLOBALS->change = 0;
 
+	/* open the new wallet assistant */
+	if(file_clear == TRUE)
+	{
+		ui_start_assistant();
+	}
+	
 }
 
 
@@ -954,7 +1089,8 @@ struct wallet_data *data;
 GtkTreeModel *model;
 GtkTreeIter  iter;
 GList *list;
-
+gdouble total = 0;
+	
 	DB( g_printf("(wallet) refresh upcoming\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
@@ -977,12 +1113,25 @@ GList *list;
 			gtk_list_store_append (GTK_LIST_STORE(model), &iter);
 			gtk_list_store_set (GTK_LIST_STORE(model), &iter,
 				  LST_DSPUPC_DATAS, arc,
+			      LST_DSPUPC_WORDING, arc->wording,
+			      LST_DSPUPC_AMOUNT, arc->amount,
 				  LST_DSPUPC_REMAINING, decay,
 				  -1);
+
+			total += arc->amount;
 		}
 		list = g_list_next(list);
 	}
 
+	// insert total
+	gtk_list_store_append (GTK_LIST_STORE(model), &iter);
+	gtk_list_store_set (GTK_LIST_STORE(model), &iter,
+		  LST_DSPUPC_DATAS, NULL,
+	      LST_DSPUPC_WORDING, _("<b>Total</b>"),
+	      LST_DSPUPC_AMOUNT, total,
+		  -1);
+
+	
 }
 
 /*
@@ -1064,11 +1213,13 @@ gint usermode = GPOINTER_TO_INT(user_data);
 
 					/* todo: update acc flags */
 					acc = da_acc_get(arc->account);
-					acc->flags |= AF_ADDED;
+					if(acc)
+						acc->flags |= AF_ADDED;
 					if(arc->paymode == PAYMODE_INTXFER)
 					{
 						acc = da_acc_get(arc->dst_account);
-						acc->flags |= AF_ADDED;
+						if(acc)
+							acc->flags |= AF_ADDED;
 					}
 
 					/* compute next occurence */
@@ -1683,6 +1834,7 @@ gint flags;
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->manager, "/MenuBar/OperationMenu/AddOpe"), sensitive);
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->manager, "/MenuBar/OperationMenu/ShowOpe"), sensitive);
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->manager, "/MenuBar/ReportMenu/Statistics"), sensitive);
+		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->manager, "/MenuBar/ReportMenu/TrendTime"), sensitive);
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->manager, "/MenuBar/ReportMenu/BudgetR"), sensitive);
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->manager, "/MenuBar/ReportMenu/Overdrawn"), sensitive);
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->manager, "/MenuBar/ReportMenu/Carcost"), sensitive);
@@ -2298,17 +2450,14 @@ GError *error = NULL;
 	g_object_set (action,
 		      "short_label", _("Open"),
 		      NULL);
-	gtk_action_connect_proxy (action, GTK_WIDGET (open_button));
-
+	//gtk_action_connect_proxy (action, GTK_WIDGET (open_button));
+	gtk_activatable_set_related_action (GTK_ACTIVATABLE (open_button), action);
 
 	gtk_toolbar_insert (GTK_TOOLBAR (data->toolbar),
 			    open_button,
 			    1);
 	/* end testing */
 
-
-
-
 }
 
 
