@@ -909,6 +909,11 @@ static const double dashed3[] = {2.0};
 	/* draw vertical lines + legend */
 	if(chart->show_xval)
 	{
+	gint blkw = chart->barw;
+
+		if( chart->dual )
+			blkw = blkw * 2;
+
 		x = chart->ox + 1 + (chart->barw/2);
 		y = chart->oy;
 		first = (gint)gtk_adjustment_get_value(GTK_ADJUSTMENT(chart->adjustment));
@@ -926,7 +931,7 @@ static const double dashed3[] = {2.0};
 
 			}
 
-			x += chart->barw;
+			x += blkw;
 		}
 	}
 
@@ -1000,6 +1005,12 @@ cairo_text_extents_t extents;
 	/* draw y-legend (amount) */
 	if(chart->show_xval)
 	{
+	gint blkw = chart->barw;
+
+		if( chart->dual )
+			blkw = blkw * 2;
+
+
 		x = chart->ox + 1 + (chart->barw/2);
 		y = chart->oy;
 		first = (gint)gtk_adjustment_get_value(GTK_ADJUSTMENT(chart->adjustment));
@@ -1023,7 +1034,7 @@ cairo_text_extents_t extents;
 				cairo_stroke(cr);
 			}
 
-			x += chart->barw;
+			x += blkw;
 		}
 	}
 
