@@ -20,6 +20,7 @@
 #include "homebank.h"
 
 #include "hb_payee.h"
+#include "import.h"
 
 /****************************************************************************/
 /* Debug macros										 */
@@ -178,10 +179,19 @@ payee_load_csv(gchar *filename)
 GIOChannel *io;
 gchar *tmpstr;
 gint io_stat;
+const gchar *encoding;
 
+	encoding = homebank_file_getencoding(filename);
+	
 	io = g_io_channel_new_file(filename, "r", NULL);
 	if(io != NULL)
 	{
+		DB( g_print(" -> encoding should be %s\n", encoding) );
+		if( encoding != NULL )
+		{
+			g_io_channel_set_encoding(io, encoding, NULL);
+		}
+
 		for(;;)
 		{
 			io_stat = g_io_channel_read_line(io, &tmpstr, NULL, NULL, NULL);
