@@ -326,7 +326,8 @@ gint changes = 0;
 								changes++;
 							}
 		
-			
+							g_free(word);
+							g_free(needle);
 			
 						}
 					}
