@@ -50,6 +50,7 @@ static gchar *images_dir   = NULL;
 static gchar *pixmaps_dir  = NULL;
 static gchar *locale_dir   = NULL;
 static gchar *help_dir     = NULL;
+static gchar *datas_dir    = NULL;
 
 
 #define MARKUP_STRING "<span size='small'>%s</span>"
@@ -508,7 +509,13 @@ static gint csvtype[7] = {
 					else
 					
 					// QIF file ?
-					if( g_str_has_prefix(tmpstr, "!Type:") || g_str_has_prefix(tmpstr, "!Option:") || g_str_has_prefix(tmpstr, "!Account"))
+					if( g_str_has_prefix(tmpstr, "!Type:") || 
+					    g_str_has_prefix(tmpstr, "!type:") || 
+					    g_str_has_prefix(tmpstr, "!Option:") ||
+					    g_str_has_prefix(tmpstr, "!option:") || 
+					    g_str_has_prefix(tmpstr, "!Account") ||
+					    g_str_has_prefix(tmpstr, "!account") 
+					    )
 					{
 						DB( g_print(" type is QIF\n") );
 						retval = FILETYPE_QIF;
@@ -635,6 +642,23 @@ gchar *dirname;
 }
 
 
+static gboolean homebank_copy_file(gchar *srcfile, gchar *dstfile)
+{
+gchar *buffer;
+gsize length;
+GError *error = NULL;
+gboolean retval = FALSE;
+	
+	if (g_file_get_contents (srcfile, &buffer, &length, &error))
+	{
+		if(g_file_set_contents(dstfile, buffer, length, NULL))
+		{
+			retval = TRUE;
+		}
+	}
+	return retval;
+}
+
 
 
 void homebank_backup_current_file(gchar *pathname)
@@ -662,9 +686,11 @@ int retval;
 			g_remove(newname);
 		}
 
-		DB( g_print("rename %s => %s\n", pathname, newname) );
+		DB( g_print("copy %s => %s\n", pathname, newname) );
 
-		retval = g_rename(pathname, newname);
+		retval = homebank_copy_file (pathname, newname);
+		//#512046 
+		//retval = g_rename(pathname, newname);
 		
 		DB( g_print("retval %d\n", retval) );
 		
@@ -1000,6 +1026,13 @@ homebank_app_get_help_dir (void)
 	return help_dir;
 }
 
+const gchar *
+homebank_app_get_datas_dir (void)
+{
+	return datas_dir;
+}
+
+
 /* build package paths at runtime */
 static void
 build_package_paths (void)
@@ -1008,16 +1041,18 @@ build_package_paths (void)
 	gchar *prefix;
 	
 	prefix = g_win32_get_package_installation_directory (NULL, NULL);
+	locale_dir   = g_build_filename (prefix, "share", "locale", NULL);
 	images_dir   = g_build_filename (prefix, "share", PACKAGE, "images", NULL);
 	pixmaps_dir  = g_build_filename (prefix, "share", PACKAGE, "icons", NULL);
 	help_dir     = g_build_filename (prefix, "share", PACKAGE, "help", NULL);
-	locale_dir   = g_build_filename (prefix, "share", "locale", NULL);
+	datas_dir     = g_build_filename (prefix, "share", PACKAGE, "datas", NULL);
 	g_free (prefix);
 #else
+	locale_dir   = g_build_filename (DATA_DIR, "locale", NULL);
 	images_dir   = g_build_filename (SHARE_DIR, "images", NULL);
-	pixmaps_dir  = g_strdup (HOMEBANK_PIXMAPSDIR);
-	locale_dir   = g_strdup (HOMEBANK_LOCALEDIR);
-	help_dir     = g_strdup (HOMEBANK_HELPDIR);
+	pixmaps_dir  = g_build_filename (DATA_DIR, PACKAGE, "icons", NULL);
+	help_dir     = g_build_filename (DATA_DIR, PACKAGE, "help", NULL);
+	datas_dir     = g_build_filename (DATA_DIR, PACKAGE, "datas", NULL);
 #endif
 
 	config_dir   = g_build_filename(g_get_user_config_dir(), HB_DATA_PATH, NULL);
@@ -1027,6 +1062,7 @@ build_package_paths (void)
 	DB( g_print("pixmaps_dir: %s\n", pixmaps_dir) );
 	DB( g_print("locale_dir : %s\n", locale_dir) );
 	DB( g_print("help_dir   : %s\n", help_dir) );
+	DB( g_print("datas_dir  : %s\n", datas_dir) );
 
 }
 
@@ -1080,6 +1116,7 @@ gboolean exists;
 	{
 		/* just update folder security */
 		g_chmod(configdir, 0700);
+		GLOBALS->first_run = FALSE;
 	}
 	else
 	{
@@ -1103,6 +1140,7 @@ gboolean exists;
 			}
 		}
 		g_free(homedir);
+		GLOBALS->first_run = TRUE;
 	}
 	
 }
@@ -1224,8 +1262,8 @@ GDate *date;
 	g_print("user_cache_dir: %s\n", g_get_user_cache_dir());
 	g_print("user_data_dir: %s\n", g_get_user_data_dir ());
 	g_print("user_config_dir: %s\n", g_get_user_config_dir ());
-	g_print("system_data_dirs: %s\n", g_get_system_data_dirs ());
-	g_print("system_config_dirs: %s\n", g_get_system_config_dirs ());
+	//g_print("system_data_dirs: %s\n", g_get_system_data_dirs ());
+	//g_print("system_config_dirs: %s\n", g_get_system_config_dirs ());
 
 	g_print("home_dir: %s\n", g_get_home_dir ());
 	g_print("tmp_dir: %s\n", g_get_tmp_dir ());
@@ -1314,7 +1352,6 @@ gboolean openlast;
 
 #endif
 
-
 	/* Set up option groups */
 	option_context = g_option_context_new (NULL);
 	
@@ -1440,6 +1477,12 @@ gboolean openlast;
 			gtk_widget_destroy (dialog);
 #endif
 
+			if(GLOBALS->first_run)
+			{
+				wallet_action_help_welcome();
+			}
+
+			
 			while (gtk_events_pending ()) /* make sure splash is gone */
 				gtk_main_iteration ();
 
