@@ -59,9 +59,9 @@
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 #define HB_UNSTABLE			0
-#define HB_VERSION			"4.2.1"
+#define HB_VERSION			"4.3"
 
-#define FILE_VERSION		0.4
+#define FILE_VERSION		0.5
 
 #if HB_UNSTABLE != 1
 	#define	PROGNAME		"HomeBank"
@@ -154,6 +154,8 @@ struct HomeBank
 	GList		*arc_list;		//archives
 	GList		*ope_list;		//operations
 
+	gboolean	first_run;
+	
 	// wallet properties
 	gchar		*title;
 	guint		car_category;
@@ -200,5 +202,6 @@ const gchar *homebank_app_get_images_dir (void);
 const gchar *homebank_app_get_pixmaps_dir (void);
 const gchar *homebank_app_get_locale_dir (void);
 const gchar *homebank_app_get_help_dir (void);
+const gchar *homebank_app_get_datas_dir (void);
 
 #endif /* __HOMEBANK_H__ */
