@@ -298,7 +298,7 @@ gint type = QIF_NONE;
 	//DB( g_print(" -> str: %s type: %d\n", tmpstr, type) );
 
 
-	if(g_str_has_prefix(tmpstr, "!Account"))
+	if(g_str_has_prefix(tmpstr, "!Account") || g_str_has_prefix(tmpstr, "!account"))
 	{
 		type = QIF_ACCOUNT;
 	}
@@ -308,48 +308,51 @@ gint type = QIF_NONE;
 
 		if( g_strv_length(typestr) == 2 )
 		{
-
+			gchar *tmpstr = g_utf8_casefold(typestr[1], -1);
+			
 			//DB( g_print(" -> str[1]: %s\n", typestr[1]) );
 
-			if( g_str_has_prefix(typestr[1], "Bank") )
+			if( g_str_has_prefix(tmpstr, "bank") )
 			{
 				type = QIF_TRANSACTION;
 			}
 			else
-			if( g_str_has_prefix(typestr[1], "Cash") )
+			if( g_str_has_prefix(tmpstr, "cash") )
 			{
 				type = QIF_TRANSACTION;
 			}
 			else
-			if( g_str_has_prefix(typestr[1], "CCard") )
+			if( g_str_has_prefix(tmpstr, "ccard") )
 			{
 				type = QIF_TRANSACTION;
 			}
 			else
-			if( g_str_has_prefix(typestr[1], "Invst") )
+			if( g_str_has_prefix(tmpstr, "invst") )
 			{
 				type = QIF_TRANSACTION;
 			}
 			else
-			if( g_str_has_prefix(typestr[1], "Oth A") )
+			if( g_str_has_prefix(tmpstr, "oth a") )
 			{
 				type = QIF_TRANSACTION;
 			}
 			else
-			if( g_str_has_prefix(typestr[1], "Oth L") )
+			if( g_str_has_prefix(tmpstr, "oth l") )
 			{
 				type = QIF_TRANSACTION;
 			}
 			else
-			if( g_str_has_prefix(typestr[1], "Security") )
+			if( g_str_has_prefix(tmpstr, "security") )
 			{
 				type = QIF_SECURITY;
 			}
 			else
-			if( g_str_has_prefix(typestr[1], "Prices") )
+			if( g_str_has_prefix(tmpstr, "prices") )
 			{		
 				type = QIF_PRICES;
 			}
+
+			g_free(tmpstr);
 		}		
 		g_strfreev(typestr);							
 	}
@@ -379,7 +382,6 @@ QIF_Tran tran = { 0 };
 	gchar *cur_acc;
 
 		DB( g_print(" -> encoding should be %s\n", encoding) );
-
 		if( encoding != NULL )
 		{
 			g_io_channel_set_encoding(io, encoding, NULL);
@@ -906,7 +908,10 @@ size_t rc;
 
 					if( trans->paymode == PAYMODE_INTXFER && trans->account == item->key)
 					{
-						g_string_append_printf (buffer, "L[%s]\n", item->name);
+					//#579260
+						Account *dstacc = da_acc_get(trans->dst_account);
+						if(dstacc)
+							g_string_append_printf (buffer, "L[%s]\n", dstacc->name);
 					}
 					else
 					{
