@@ -75,16 +75,80 @@ void ui_acc_affect_listview_add(GtkTreeView *treeview, Account *item);
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
-
-
-/*
-** try to determine the file type (if supported for import by homebank)
-**
-**
-*/
-static const gchar *homebank_file_getencoding(gchar *filename)
+static gchar *homebank_utf8_convert(gchar *buffer, const gchar **charset)
 {
-const gchar *retval = NULL;
+GError *conv_error;
+gchar* conv_buffer = NULL;
+gsize new_len;
+guint i;
+gboolean valid;
+const struct _GeditEncoding *enc;
+
+	DB( g_print("(homebank) homebank_utf8_convert\n") );
+
+	for (i=0 ; i<GEDIT_ENCODING_LAST ; i++)
+	{
+		conv_error = NULL;
+
+		enc = gedit_encoding_get_from_index(i);
+		DB( g_print("-> should try %s\n",  enc->charset) );
+
+		conv_buffer = g_convert(buffer, -1, "UTF-8", enc->charset, NULL, &new_len, &conv_error); 
+		valid = g_utf8_validate (conv_buffer, -1, NULL);
+		if ((conv_error != NULL) || !valid )
+		{
+			DB( g_print ("  -> Couldn't convert from %s to UTF-8.\n", enc->charset) );
+		}				
+		else
+		{
+			DB( g_print ("  -> file compatible with '%s'\n", enc->charset) );
+			if(charset != NULL)
+				*charset = enc->charset;
+			return conv_buffer;
+		}
+	}
+
+	if(charset != NULL)
+		*charset = NULL;	
+	return NULL;
+}
+
+
+/* 
+ * Ensure a buffer to be utf-8, and convert if necessary
+ *
+ */
+gchar *homebank_utf8_ensure(gchar *buffer)
+{
+gboolean isvalid;
+gchar *converted;
+
+	DB( g_print("(homebank) homebank_utf8_ensure\n") );
+
+	if(buffer == NULL)
+		return NULL;
+	
+	isvalid = g_utf8_validate(buffer, -1, NULL);
+	DB( g_print(" -> is valid utf8: %d\n", isvalid) );
+
+	if(!isvalid)
+	{
+		converted = homebank_utf8_convert(buffer, NULL);
+		if(converted != NULL)
+		{
+			//g_warn here ?
+			g_free(buffer);
+			return converted;
+		}
+		//g_warn here ?
+	}
+	return buffer;
+}
+
+
+const gchar *homebank_file_getencoding(gchar *filename)
+{
+const gchar *charset = NULL;
 gchar *buffer;
 gsize length;
 GError *error = NULL;
@@ -92,7 +156,7 @@ gboolean isutf8;
 const gchar *locale_charset;
 const struct _GeditEncoding *enc;
 
-	DB( g_print("(import) test encoding\n") );
+	DB( g_print("(homebank) test encoding\n") );
 
 	if (g_get_charset (&locale_charset) == FALSE)
 	{
@@ -104,75 +168,35 @@ const struct _GeditEncoding *enc;
 
 	if (g_file_get_contents (filename, &buffer, &length, &error))
 	{
-	gint i;
 	
 		isutf8 = g_utf8_validate(buffer, -1, NULL);
 		DB( g_print(" -> is valid utf8: %d\n", isutf8) );
 
 		if( isutf8 == FALSE )
 		{
-		GError *conv_error = NULL;
-		gchar* converted_contents = NULL;
-		gsize bytes_read, new_len;
-
-			for(i=0;i<GEDIT_ENCODING_LAST;i++)
-			{
-		
-				conv_error = NULL;
-		
-				enc = gedit_encoding_get_from_index(i);
-				DB( g_print("-> should try %s\n",  enc->charset) );
-		
-			converted_contents = g_convert (buffer, 
-					-1, 
-					"UTF-8",
-					enc->charset, 
-					&bytes_read, 
-					&new_len,
-					&conv_error); 
-
-			isutf8 = g_utf8_validate (converted_contents, new_len, NULL);
-			if ((conv_error != NULL) || 
-				!isutf8 )
-			{
-				//probleme
-				DB( g_print ("  -> Couldn't convert from %s to UTF-8.\n", enc->charset) );
-				
-
-			}				
-			else
-			{
-				DB( g_print ("  -> file compatible with '%s'\n", enc->charset) );
+		gchar *converted;
 			
-			}
+			converted = homebank_utf8_convert(buffer, &charset);
 
-
-				g_free(converted_contents);
-		
-				//fixed: 370922
-				if( isutf8 == TRUE )
-				{
-					
-					retval = enc->charset;
-					break;
-				}
-				
-		
-			}
+			DB( g_print(" -> converted charset match: '%s'\n", charset) );
+			DB( g_print(" -> converted: '%x' %s\n", converted, converted) );
+			
+			if(converted != NULL)
+				g_free(converted);
 		}
 		else
 		{
 			enc = gedit_encoding_get_utf8();
-			retval = enc->charset;
+			charset = enc->charset;
 		}
 		
 	
 		g_free(buffer);	
 	}
 
-	DB( g_print ("  -> retval is '%s'\n", retval) );
+	DB( g_print ("  -> charset is '%s'\n", charset) );
 
-	return retval;
+	return charset;
 }
 
 
@@ -604,7 +628,10 @@ Operation *newope;
 					newope->paymode = PAYMODE_CASH;
 				break;
 			case OFX_POS:
+				if(ctx->curr_acc && ctx->curr_acc->type == ACC_TYPE_CREDITCARD)
 					newope->paymode = PAYMODE_CCARD;
+				else
+					newope->paymode = PAYMODE_DCARD;
 				break;
 			case OFX_XFER:
 					newope->paymode = PAYMODE_XFER;
@@ -641,6 +668,14 @@ Operation *newope;
 
 		newope->account = ctx->curr_acc->key;
 		newope->flags |= OF_ADDED;	
+
+		/* ensure utf-8 here, has under windows, libofx not always return utf-8 as it should */
+	#ifndef G_OS_UNIX
+		DB( printf(" ensure UTF-8\n") );
+
+		newope->info = homebank_utf8_ensure(newope->info);
+		newope->wording = homebank_utf8_ensure(newope->wording);
+	#endif
 		
 		ctx->trans_list = g_list_append(ctx->trans_list, newope);
 
@@ -735,7 +770,7 @@ GList *list;
 	DB( g_print("(import) clear all\n") );
 
 	// clear the active file into filechooser
-	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(data->filechooser), PREFS->path_import);
+	//gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(data->filechooser), PREFS->path_import);
 	//gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(data->filechooser), "");
 	
 	// clear transactions
@@ -1354,7 +1389,7 @@ guint32 key;
 gint row;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-	DB( g_printf("(import) edit target account\n", data) );
+	DB( g_printf("(import) edit target account\n") );
 
 	key = ui_acc_affect_listview_get_selected_key(GTK_TREE_VIEW(data->LV_acc));
 	if( key > 0 )
@@ -1616,6 +1651,12 @@ gchar *title;
 		case PAGE_OPTIONS:
 			DB( g_print(" -> 3 real import\n") );
 			//gtk_assistant_set_current_page(GTK_ASSISTANT (widget), PAGE_IMPORT);
+
+			/* remind folder to preference */
+			gchar *folder = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(data->filechooser));
+			g_free(PREFS->path_import);
+			PREFS->path_import = folder;
+
 			
 			import_clearall(data);
 			
@@ -2036,7 +2077,7 @@ GtkWidget *vbox, *align, *hbox, *label, *sw, *widget, *expander;
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-	widget = create_list_operation(PREFS->lst_ope_columns);
+	widget = create_list_operation(TRN_LIST_TYPE_DETAIL, PREFS->lst_ope_columns);
 	data->duplicat_ope = widget;
 	gtk_container_add (GTK_CONTAINER (sw), widget);
 
@@ -2295,6 +2336,11 @@ gint pos;
 	assistant = gtk_assistant_new ();
 	data->assistant = assistant;
 
+	//store our window private data
+	g_object_set_data(G_OBJECT(assistant), "inst_data", (gpointer)data);
+	//DB( g_print("** (import) window=%x, inst_data=%x\n", assistant, data) );
+	
+	
 	gtk_window_set_modal(GTK_WINDOW (assistant), TRUE);
 	gtk_window_set_transient_for(GTK_WINDOW(assistant), GTK_WINDOW(GLOBALS->mainwindow));
 
@@ -2333,9 +2379,6 @@ gint pos;
 	//gtk_window_set_position (GTK_WINDOW (assistant), GTK_WIN_POS_CENTER);
 #endif
 
-	//store our window private data
-	g_object_set_data(G_OBJECT(assistant), "inst_data", (gpointer)data);
-	//DB( g_print("** (import) window=%x, inst_data=%x\n", assistant, data) );
 
 	pos = 0;
 	data->pages[pos++] = create_page1 (assistant, data);	// intro
@@ -2373,6 +2416,9 @@ gint pos;
 	g_signal_connect (G_OBJECT (assistant), "prepare",
 		G_CALLBACK (on_assistant_prepare), NULL);
 
+//    g_signal_connect (window, "delete-event", G_CALLBACK (wallet_dispose), (gpointer)data);
+
+	
 	gtk_widget_show (assistant);
 
 	return assistant;
