@@ -74,6 +74,18 @@ static   gint
  			ret = ope1->date - ope2->date;
 			break;
 
+		case LST_DSPOPE_ACCOUNT:
+			{
+			Account *p1, *p2;
+			
+				p1 = da_acc_get(ope1->account);
+				p2 = da_acc_get(ope2->account);
+				
+				if( p1->name && p2->name ) 
+					ret = g_utf8_collate(p1->name, p2->name);
+			}
+			break;
+
 		case LST_DSPOPE_INFO:
 			if(!(ret = ope1->paymode - ope2->paymode))
 			{
@@ -187,6 +199,24 @@ GdkPixbuf *pixbuf = NULL;
 	g_object_set(renderer, "pixbuf", pixbuf, NULL);
 }
 
+
+/*
+** account cell function
+*/
+static void ope_account_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+{
+Operation *ope;
+Account *acc;
+
+	gtk_tree_model_get(model, iter, LST_DSPOPE_DATAS, &ope, -1);
+
+	acc = da_acc_get(ope->account);
+	if( acc )
+	{
+		g_object_set(renderer, "text", acc->name, NULL);
+	}
+}
+
 /*
 ** date cell function
 */
@@ -502,37 +532,6 @@ gint id;
 }
 
 
-//todo: this will not work (mem freed before return)
-/*
-gint *list_operation_get_columns(GtkTreeView *treeview)
-{
-gint columns[NUM_LST_DSPOPE + 1];
-GList *list, *tmp;
-GtkTreeViewColumn *column;
-gint id, i = 0;
-
-	DB( g_print("(list_operation_get_columns)\n") );
-
-	list = gtk_tree_view_get_columns( treeview );
-	tmp = g_list_first(list);
-	while (tmp != NULL)
-	{
-		column = tmp->data;
-		id = gtk_tree_view_column_get_sort_column_id(column);
-		columns[i] = gtk_tree_view_column_get_visible (column) ? id : -id;
-	
-		tmp = g_list_next(tmp);
-		i++;
-	}
-	
-
-
-	g_list_free(list );
-
-	return columns;
-}
-*/
-
 static void list_operation_set_columns(GtkTreeView *treeview, gint *visibility)
 {
 GtkTreeViewColumn *column, *base;
@@ -564,33 +563,6 @@ gint i = 0;
 		
 	}
 
-
-		/* old code */
-	/*
-	list = gtk_tree_view_get_columns( treeview );
-	tmp = g_list_first(list);
-	while (tmp != NULL)
-	{
-		
-		column = tmp->data;
-		id = gtk_tree_view_column_get_sort_column_id(column);
-		
-		DB( g_print(" - col %d (%s)\n", id, gtk_tree_view_column_get_title(column)) );
-		
-		if( i == (NUM_LST_DSPOPE-1) )
-		{
-			gtk_tree_view_column_set_visible (column, TRUE);
-		}
-		else
-			gtk_tree_view_column_set_visible (column, visibility[i]);
-		
-		
-		
-		tmp = g_list_next(tmp);
-		i++;
-	}
-	*/
-
 	g_list_free(list );
 }
 
@@ -601,27 +573,23 @@ gint i = 0;
 ** create our operation list
 ** State, Date, Info, Payee, Wording, (Amount), Expense, Income, Category
 */
-GtkWidget *create_list_operation(gboolean *columns)
+GtkWidget *create_list_operation(gint type, gboolean *pref_columns)
 {
 GtkListStore *store;
 GtkWidget *view;
 GtkCellRenderer    *renderer;
-GtkTreeViewColumn  *column;
+GtkTreeViewColumn  *column, *col_acc = NULL;
 
 	/* create list store */
 	store = gtk_list_store_new(
 	  	NUM_LST_DSPOPE,
-		G_TYPE_POINTER,
-		G_TYPE_BOOLEAN,
-		G_TYPE_BOOLEAN,
-		G_TYPE_BOOLEAN,
-		G_TYPE_BOOLEAN,
-		G_TYPE_BOOLEAN,
-		G_TYPE_BOOLEAN,
-		G_TYPE_BOOLEAN,
-		G_TYPE_BOOLEAN,
-		G_TYPE_BOOLEAN,
-		G_TYPE_BOOLEAN
+		G_TYPE_POINTER,	/*only really used columns, other are fake */
+		G_TYPE_BOOLEAN, G_TYPE_BOOLEAN,
+		G_TYPE_BOOLEAN, G_TYPE_BOOLEAN,
+		G_TYPE_BOOLEAN, G_TYPE_BOOLEAN,
+		G_TYPE_BOOLEAN, G_TYPE_BOOLEAN,
+		G_TYPE_BOOLEAN, G_TYPE_BOOLEAN,
+		G_TYPE_BOOLEAN, G_TYPE_BOOLEAN
 		);
 
 	//treeview
@@ -632,7 +600,8 @@ GtkTreeViewColumn  *column;
 	//gtk_tree_view_set_search_column (GTK_TREE_VIEW (treeview),
 	//			       COLUMN_DESCRIPTION);
 
-	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(view)), GTK_SELECTION_MULTIPLE);
+	if(type == TRN_LIST_TYPE_BOOK)
+		gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(view)), GTK_SELECTION_MULTIPLE);
 
 	/* column 1: Status */
 	column = gtk_tree_view_column_new();
@@ -658,6 +627,21 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
+
+	if(type == TRN_LIST_TYPE_DETAIL)
+	{
+		column = gtk_tree_view_column_new();
+		col_acc = column;
+		gtk_tree_view_column_set_title(column, _("Account"));
+		renderer = gtk_cell_renderer_text_new ();
+		gtk_tree_view_column_pack_start(column, renderer, TRUE);
+		gtk_tree_view_column_set_cell_data_func(column, renderer, ope_account_cell_data_function, NULL, NULL);
+		gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_ACCOUNT);
+		gtk_tree_view_column_set_resizable(column, TRUE);
+		gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	}
+
+	
 	/* column 2: Date */
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_title(column, _("Date"));
@@ -711,18 +695,23 @@ GtkTreeViewColumn  *column;
 
 
 
-  /* assign visibility */
-	list_operation_set_columns(GTK_TREE_VIEW(view), columns);
+  /* apply user preference for columns */
+	list_operation_set_columns(GTK_TREE_VIEW(view), pref_columns);
 
+  /* force accoutn column for detail view */
+	if(type == TRN_LIST_TYPE_DETAIL)
+	{
+		gtk_tree_view_move_column_after(GTK_TREE_VIEW(view), col_acc, NULL);
+	}
+	
   /* set initial sort order */
     DB( g_print("set sort to %d %d\n", PREFS->lst_ope_sort_id, PREFS->lst_ope_sort_order) );
-    
-    
     gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), PREFS->lst_ope_sort_id, PREFS->lst_ope_sort_order);
 
 
 	/* signals */
-	g_signal_connect (GTK_TREE_SORTABLE(store), "sort-column-changed", G_CALLBACK (list_operation_sort_column_changed), NULL);
+	if(type == TRN_LIST_TYPE_BOOK)
+		g_signal_connect (GTK_TREE_SORTABLE(store), "sort-column-changed", G_CALLBACK (list_operation_sort_column_changed), NULL);
 
 	return(view);
 }
@@ -733,7 +722,7 @@ GtkTreeViewColumn  *column;
 /*
 ** account cell function
 */
-static void ope_account_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void ope_importaccount_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Operation *ope;
 Account *acc, *dacc;
@@ -883,7 +872,7 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_column_set_title(column, _("Account"));
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_account_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_importaccount_cell_data_function, NULL, NULL);
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_DATE);
 	gtk_tree_view_column_set_resizable(column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
