@@ -30,21 +30,28 @@ extern struct Preferences *PREFS;
 */
 static void date_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
-Archive *item;
+Archive *arc;
 gchar buffer[256];
 GDate *date;
 
 	gtk_tree_model_get(model, iter,
-		LST_DSPUPC_DATAS, &item,
+		LST_DSPUPC_DATAS, &arc,
 		-1);
 
-	date = g_date_new_julian (item->nextdate);
-	g_date_strftime (buffer, 256-1, PREFS->date_format, date);
-	g_date_free(date);
+	if(arc)
+	{
+		date = g_date_new_julian (arc->nextdate);
+		g_date_strftime (buffer, 256-1, PREFS->date_format, date);
+		g_date_free(date);
 
-	//g_snprintf(buf, sizeof(buf), "%d", ope->ope_Date);
+		//g_snprintf(buf, sizeof(buf), "%d", ope->ope_Date);
+
+		g_object_set(renderer, "text", buffer, NULL);
+
+	}
+		else
+		g_object_set(renderer, "text", NULL, NULL);
 
-    g_object_set(renderer, "text", buffer, NULL);
 }
 
 /*
@@ -59,10 +66,17 @@ Payee *pay;
 		LST_DSPUPC_DATAS, &arc,
 		-1);
 
-	pay = da_pay_get(arc->payee);
+	if(arc)
+	{
+
+		pay = da_pay_get(arc->payee);
+
+		if(pay != NULL)    
+			g_object_set(renderer, "text", pay->name, NULL);
+	}
+		else
+		g_object_set(renderer, "text", NULL, NULL);
 
-	if(pay != NULL)    
-    	g_object_set(renderer, "text", pay->name, NULL);
 }
 
 /*
@@ -70,13 +84,13 @@ Payee *pay;
 */
 static void wording_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
-Archive *arc;
+gchar *txt;
 
 	gtk_tree_model_get(model, iter,
-		LST_DSPUPC_DATAS, &arc,
+		LST_DSPUPC_WORDING, &txt,
 		-1);
-    //if( arc != NULL && arc->wording != NULL)
-        g_object_set(renderer, "text", arc->wording, NULL);
+	g_object_set(renderer, "markup", txt, NULL);
+
 }
 
 
@@ -85,41 +99,76 @@ Archive *arc;
 */
 static void amount_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
-Archive *item;
+Archive *arc;
+gdouble amount;
 gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
 gchar *color;
+	gint weight;
 
-	gtk_tree_model_get(model, iter, LST_DSPUPC_DATAS, &item, -1);
-	color = get_normal_color_amount(item->amount);
-
-	mystrfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, item->amount, GLOBALS->minor);
+	gtk_tree_model_get(model, iter, LST_DSPUPC_AMOUNT, &amount, LST_DSPUPC_DATAS, &arc, -1);
+	color = get_normal_color_amount(amount);
+	weight = arc == NULL ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL;
+	
+	mystrfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, amount, GLOBALS->minor);
 	g_object_set(renderer, 
+	    "weight", weight,
 		"foreground",  color,
 		"text", buf,
 		NULL);
 }
 
+/*
+** account cell function
+*/
+static void account_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+{
+Archive *arc;
+Account *acc;
+
+	gtk_tree_model_get(model, iter, LST_DSPUPC_DATAS, &arc, -1);
+	if(arc)
+	{
+
+	
+		acc = da_acc_get(arc->account);
+		if( acc )
+		{
+			g_object_set(renderer, "text", acc->name, NULL);
+		}
+	}
+	else
+		g_object_set(renderer, "text", NULL, NULL);
+
+}
+
 
 /*
 ** remaining cell function
 */
 static void remaining_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
-Archive *item;
+Archive *arc;
 gchar *markuptxt;
 guint decay;
 
 	gtk_tree_model_get(model, iter,
-		LST_DSPUPC_DATAS, &item,
+		LST_DSPUPC_DATAS, &arc,
 		-1);
 
-	decay = item->nextdate - GLOBALS->today;
+	if(arc)
+	{
 
-	markuptxt = g_strdup_printf("%d days", decay);
+		decay = arc->nextdate - GLOBALS->today;
+
+		markuptxt = g_strdup_printf("%d days", decay);
 	
 
-    g_object_set(renderer, "markup", markuptxt, NULL);
-    g_free(markuptxt);
+		g_object_set(renderer, "markup", markuptxt, NULL);
+		g_free(markuptxt);
+	}
+	else
+		g_object_set(renderer, "text", NULL, NULL);
+
 }
 
 
@@ -134,11 +183,12 @@ GtkTreeViewColumn  *column;
 	store = gtk_list_store_new(
 	  	NUM_LST_DSPUPC,
 		G_TYPE_POINTER,
-		G_TYPE_BOOLEAN,	/* fake column */
-		G_TYPE_BOOLEAN,	/* fake column */
-		G_TYPE_BOOLEAN,	/* fake column */
-		G_TYPE_BOOLEAN,	/* fake column */
-		G_TYPE_INT
+		G_TYPE_BOOLEAN,	/* payee */
+		G_TYPE_STRING,	/* wording */
+		G_TYPE_DOUBLE,	/* amount */
+		G_TYPE_BOOLEAN,	/* account */
+	    G_TYPE_BOOLEAN,	/* next on */	    
+		G_TYPE_INT		/* remianing */
 		);
 
 	//treeview
@@ -187,6 +237,16 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
+	/* column: Account */
+	column = gtk_tree_view_column_new();
+	gtk_tree_view_column_set_title(column, _("Account"));
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, account_cell_data_function, NULL, NULL);
+	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_DATE);
+	gtk_tree_view_column_set_resizable(column, TRUE);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	
 	/* column: Next on */
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_title(column, _("Next on"));
