@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2009 Maxime DOYEN
+ *  Copyright (C) 1995-2010 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -91,8 +91,9 @@ struct lconv *lc = localeconv();
 	DB( g_print(" -> grouping_char: '%s'\n", PREFS->base_cur.grouping_char) );
 	
 	PREFS->base_cur.frac_digits   = lc->frac_digits;
-	//fix 378992
-	if( lc->frac_digits > MAX_FRAC_DIGIT )
+
+	//fix 378992/421228
+	if( PREFS->base_cur.frac_digits > MAX_FRAC_DIGIT )
 		PREFS->base_cur.frac_digits = MAX_FRAC_DIGIT;
 
 
@@ -215,6 +216,7 @@ gint i;
 	homebank_pref_init_wingeometry(&PREFS->wal_wg, 0, 0, 640, 480);
 	homebank_pref_init_wingeometry(&PREFS->acc_wg, 0, 0, 640, 480);
 	homebank_pref_init_wingeometry(&PREFS->sta_wg, 0, 0, 640, 480);
+	homebank_pref_init_wingeometry(&PREFS->tme_wg, 0, 0, 640, 480);
 	homebank_pref_init_wingeometry(&PREFS->ove_wg, 0, 0, 640, 480);
 	homebank_pref_init_wingeometry(&PREFS->bud_wg, 0, 0, 640, 480);
 	homebank_pref_init_wingeometry(&PREFS->car_wg, 0, 0, 640, 480);
@@ -481,8 +483,7 @@ GError *error = NULL;
 	keyfile = g_key_file_new();
 	if(keyfile)
 	{
-		//filename = g_strdup_printf("%s/" HB_DATA_PATH "/preferences", g_get_home_dir ());
-		filename = g_build_filename(g_get_home_dir (), HB_DATA_PATH, "preferences", NULL );
+		filename = g_build_filename(homebank_app_get_config_dir(), "preferences", NULL );
 
 		DB( g_print(" filename: %s\n", filename) );
 
@@ -577,6 +578,7 @@ GError *error = NULL;
 				homebank_pref_get_wingeometry(keyfile, group, "Wal", &PREFS->wal_wg);
 				homebank_pref_get_wingeometry(keyfile, group, "Acc", &PREFS->acc_wg);
 				homebank_pref_get_wingeometry(keyfile, group, "Sta", &PREFS->sta_wg);
+				homebank_pref_get_wingeometry(keyfile, group, "Tme", &PREFS->tme_wg);
 				homebank_pref_get_wingeometry(keyfile, group, "Ove", &PREFS->ove_wg);
 				homebank_pref_get_wingeometry(keyfile, group, "Bud", &PREFS->bud_wg);
 				homebank_pref_get_wingeometry(keyfile, group, "Car", &PREFS->car_wg);
@@ -604,6 +606,10 @@ GError *error = NULL;
 					homebank_pref_get_string(keyfile, group, "DecChar"  , &PREFS->base_cur.decimal_char);
 					homebank_pref_get_string(keyfile, group, "GroupChar", &PREFS->base_cur.grouping_char);
 					homebank_pref_get_short(keyfile, group, "FracDigits", &PREFS->base_cur.frac_digits);
+
+					//fix 378992/421228
+					if( PREFS->base_cur.frac_digits > MAX_FRAC_DIGIT )
+						PREFS->base_cur.frac_digits = MAX_FRAC_DIGIT;
 				}
 
 				homebank_pref_get_boolean(keyfile, group, "UKUnits", &PREFS->imperial_unit);
@@ -638,6 +644,11 @@ GError *error = NULL;
 					homebank_pref_get_string(keyfile, group, "DecChar"  , &PREFS->minor_cur.decimal_char);
 					homebank_pref_get_string(keyfile, group, "GroupChar", &PREFS->minor_cur.grouping_char);
 					homebank_pref_get_short(keyfile, group, "FracDigits", &PREFS->minor_cur.frac_digits);
+
+					//fix 378992/421228
+					if( PREFS->minor_cur.frac_digits > MAX_FRAC_DIGIT )
+						PREFS->minor_cur.frac_digits = MAX_FRAC_DIGIT;
+
 				}			
 
 			//PREFS->euro_symbol = g_locale_to_utf8(tmpstr, -1, NULL, NULL, NULL);
@@ -648,7 +659,10 @@ GError *error = NULL;
 				homebank_pref_get_boolean(keyfile, group, "StatDetail", &PREFS->stat_showdetail);
 				homebank_pref_get_boolean(keyfile, group, "StatRate", &PREFS->stat_showrate);
 				homebank_pref_get_boolean(keyfile, group, "BudgDetail", &PREFS->budg_showdetail);
-		
+
+			group = "Exchange";
+				homebank_pref_get_integer(keyfile, group, "OfxMemo", &PREFS->dtex_ofxmemo);
+
 
 			//group = "Chart";
 			//PREFS->chart_legend = g_key_file_get_boolean (keyfile, group, "Legend", NULL);
@@ -741,6 +755,7 @@ gsize length;
 		g_key_file_set_integer_list(keyfile, group, "Wal", (gint *)&PREFS->wal_wg, 4);
 		g_key_file_set_integer_list(keyfile, group, "Acc", (gint *)&PREFS->acc_wg, 4);
 		g_key_file_set_integer_list(keyfile, group, "Sta", (gint *)&PREFS->sta_wg, 4);
+		g_key_file_set_integer_list(keyfile, group, "Tme", (gint *)&PREFS->tme_wg, 4);
 		g_key_file_set_integer_list(keyfile, group, "Ove", (gint *)&PREFS->ove_wg, 4);
 		g_key_file_set_integer_list(keyfile, group, "Bud", (gint *)&PREFS->bud_wg, 4);
 		g_key_file_set_integer_list(keyfile, group, "Car", (gint *)&PREFS->car_wg, 4);
@@ -796,6 +811,10 @@ gsize length;
 		g_key_file_set_boolean (keyfile, group, "StatRate"    , PREFS->stat_showrate);
 		g_key_file_set_boolean (keyfile, group, "BudgDetail"  , PREFS->budg_showdetail);
 
+
+		group = "Exchange";
+		g_key_file_set_integer (keyfile, group, "OfxMemo", PREFS->dtex_ofxmemo);
+
 		//group = "Chart";
 		//g_key_file_set_boolean (keyfile, group, "Legend", PREFS->chart_legend);
 
@@ -809,8 +828,7 @@ gsize length;
 
 		//DB( g_print(" keyfile:\n%s\nlen=%d\n", contents, length) );
 
-		//filename = g_strdup_printf("%s/" HB_DATA_PATH "/preferences", g_get_home_dir ());
-		filename = g_build_filename(g_get_home_dir (), HB_DATA_PATH, "preferences", NULL );
+		filename = g_build_filename(homebank_app_get_config_dir(), "preferences", NULL );
 
 		DB( g_print(" -> filename: %s\n", filename) );
 
