@@ -585,10 +585,6 @@ gint nbmonth = 1;
 				
 			#endif
 
-
-
-
-
 			pos = 0;
 			switch(tmpfor)
 			{
@@ -645,7 +641,9 @@ gint nbmonth = 1;
 
 
 		// compute spent for each */
+		DB( g_print(" ** compute spent for each  categories\n") );
 
+		
 		list = g_list_first(GLOBALS->ope_list);
 		while (list != NULL)
 		{
@@ -659,12 +657,14 @@ gint nbmonth = 1;
 			{
 				if((acc->flags & AF_CLOSED)) goto next1;
 				if(!(acc->flags & AF_BUDGET)) goto next1;
+/*
+				//fix: #530290 
 				if( tmp_hasbudget[ope->category] == 0 )
 				{
 					DB( g_print(" -> no budget for cat %d\n", ope->category) );
 					goto next1;
 				}
-
+*/
 				if( !(ope->flags & OF_REMIND) && ope->date >= mindate && ope->date <= maxdate)
 				{
 				gint pos = 0;
@@ -1226,7 +1226,7 @@ GError *error = NULL;
 	data->GR_detail = widget;
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	treeview = create_list_operation(PREFS->lst_ope_columns);
+	treeview = create_list_operation(TRN_LIST_TYPE_DETAIL, PREFS->lst_ope_columns);
 	data->LV_detail = treeview;
 	gtk_container_add (GTK_CONTAINER(widget), treeview);
 
