@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2009 Maxime DOYEN
+ *  Copyright (C) 1995-2010 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -62,6 +62,7 @@ struct repover_data
 	GtkWidget	*CM_minor;
 	GtkWidget	*LV_report;
 	GtkWidget	*PO_acc;
+	GtkWidget	*RG_zoomx;
 
 	GtkWidget	*PO_mindate, *PO_maxdate;
 
@@ -307,22 +308,39 @@ gchar   buf[128];
 
 
 
+static void repover_zoomx_callback(GtkWidget *widget, gpointer user_data)
+{
+struct repover_data *data;
+gdouble value;
+
+	DB( g_print("(statistic) zoomx\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	value = gtk_range_get_value(GTK_RANGE(data->RG_zoomx));
+
+	DB( g_print(" + scale is %d\n", value) );
+
+	gtk_chart_set_barw(GTK_CHART(data->RE_line), value);
+
+}
+
 
 static void repover_toggle_minor(GtkWidget *widget, gpointer user_data)
 {
 struct repover_data *data;
-gboolean minor;
 
 	DB( g_print("(repover) toggle\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
+	GLOBALS->minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
+	
 	repover_update_info(widget,NULL);
 
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_report));
 
-	minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
-	gtk_chart_show_minor(GTK_CHART(data->RE_line), minor);
+	gtk_chart_show_minor(GTK_CHART(data->RE_line), GLOBALS->minor);
 }
 
 
@@ -530,7 +548,7 @@ static void repover_setup(struct repover_data *data)
 	GList *list;
 
 		//get our min max date
-		da_operation_sort(GLOBALS->ope_list);
+		GLOBALS->ope_list = da_operation_sort(GLOBALS->ope_list);
 		list = g_list_first(GLOBALS->ope_list);
 		data->mindate = ((Operation *)list->data)->date;
 		list = g_list_last(GLOBALS->ope_list);
@@ -661,6 +679,13 @@ GError *error = NULL;
 	gtk_widget_set_size_request (widget, 10, -1);
 	gtk_table_attach_defaults (GTK_TABLE (table), widget, 1, 2, row, row+1);
 
+	row++;
+	label = make_label(_("_Zoom X:"), 0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	widget = make_scale(label);
+	data->RG_zoomx = widget;
+	gtk_table_attach_defaults (GTK_TABLE (table), widget, 1, 2, row, row+1);
+
 	row++;
 	widget = gtk_check_button_new_with_mnemonic (_("_Minor currency"));
 	data->CM_minor = widget;
@@ -770,7 +795,7 @@ GError *error = NULL;
 	//page: list
 	widget = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
 	treeview = create_list_repover();
 	data->LV_report = treeview;
@@ -820,6 +845,8 @@ GError *error = NULL;
 	//let this here or the setup trigger a compute...
 	g_signal_connect (data->PO_acc, "changed", G_CALLBACK (repover_compute), NULL);
 
+	g_signal_connect (data->RG_zoomx, "value-changed", G_CALLBACK (repover_zoomx_callback), NULL);
+
 
 	/* toolbar */
 	if(PREFS->toolbar_style == 0)
