@@ -541,8 +541,11 @@ guint32 selkey;
 							include = TRUE;
 						break;
 					case REPTIME_FOR_CATEGORY:
-						if( selkey == ope->category )
+					{
+						Category *catentry = da_cat_get(ope->category);
+						if( selkey == catentry->parent || selkey == catentry->key )
 							include = TRUE;
+					}
 						break;
 					case REPTIME_FOR_PAYEE:
 						if( selkey == ope->payee )
@@ -875,8 +878,11 @@ guint32 selkey;
 							include = TRUE;
 						break;
 					case REPTIME_FOR_CATEGORY:
-						if( selkey == ope->category )
+					{
+						Category *catentry = da_cat_get(ope->category);
+						if( selkey == catentry->parent || selkey == catentry->key )
 							include = TRUE;
+					}
 						break;
 					case REPTIME_FOR_PAYEE:
 						if( selkey == ope->payee )
@@ -1572,7 +1578,7 @@ GError *error = NULL;
 	//gtk_scrolled_window_set_placement(GTK_SCROLLED_WINDOW (widget), GTK_CORNER_TOP_RIGHT);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	treeview = create_list_operation(PREFS->lst_ope_columns);
+	treeview = create_list_operation(TRN_LIST_TYPE_DETAIL, PREFS->lst_ope_columns);
 	data->LV_detail = treeview;
 	gtk_container_add (GTK_CONTAINER(widget), treeview);
 
