@@ -22,6 +22,7 @@
 
 #include "da_transaction.h"
 #include "hb_transaction.h"
+#include "import.h"
 #include "xml.h"
 
 /****************************************************************************/
@@ -70,6 +71,11 @@ struct _ParseContext
 
 };
 
+static void homebank_ugrade_v01_to_v02(void);
+static void homebank_ugrade_v02_to_v03(void);
+static void homebank_ugrade_v04_to_v05(void);
+
+
 static void
 start_element_handler (GMarkupParseContext *context,
 		       const gchar         *element_name,
@@ -419,7 +425,11 @@ gboolean rc;
 		else
 		{		
 			DB( g_print("ok file version is: %.1f\n", version) );
-		
+
+			/* 1st: validate the file is well in utf-8 */
+			buffer = homebank_utf8_ensure(buffer);
+			
+			/* then process the buffer */
 			context = g_markup_parse_context_new (&hb_parser, 0, &ctx, NULL);
 
 			error = NULL;
@@ -438,74 +448,20 @@ gboolean rc;
 			}
 
 			g_markup_parse_context_free (context);
-
-
 			g_free (buffer);
 
+
 			//upgrade to v0.2 file
-			// we must change account reference by making a +1 to its index references
 			if( version == 0.1 )
-			{
-			GList *list;
-
-				list = g_list_first(GLOBALS->ope_list);
-				while (list != NULL)
-				{
-				Operation *entry = list->data;
-					entry->account++;
-					entry->dst_account++;
-					list = g_list_next(list);
-				}
-
-				list = g_list_first(GLOBALS->arc_list);
-				while (list != NULL)
-				{
-				Archive *entry = list->data;
-					entry->account++;
-					entry->dst_account++;
-					list = g_list_next(list);
-				}
-
-			}
-
+				homebank_ugrade_v01_to_v02();
+			
 			//upgrade to v0.3 file
-			// we must assume categories exists : bugs 303886, 303738
 			if( version == 0.2 )
-			{
-			Category *cat;
-			GList *list;
+				homebank_ugrade_v02_to_v03();
 
-				list = g_list_first(GLOBALS->ope_list);
-				while (list != NULL)
-				{
-				Operation *entry = list->data;
-
-					cat = da_cat_get(entry->category);
-					if(cat == NULL)
-					{
-						DB( g_print(" !! fixing cat for ope: %d is unknow\n", entry->category) );
-						entry->category = 0;
-					}
-
-					list = g_list_next(list);
-				}
-
-				list = g_list_first(GLOBALS->arc_list);
-				while (list != NULL)
-				{
-				Archive *entry = list->data;
-
-					cat = da_cat_get(entry->category);
-					if(cat == NULL)
-					{
-						DB( g_print(" !! fixing cat for arc: %d is unknow\n", entry->category) );
-						entry->category = 0;
-					}
-
-					list = g_list_next(list);
-				}
-
-			}
+			//upgrade to v0.5 file
+			if( version == 0.4 )
+				homebank_ugrade_v04_to_v05();
 
 			//upgrade to prior v0.4 file
 			// we must sort the archive list
@@ -523,13 +479,102 @@ gboolean rc;
 }
 
 
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
+
+// v0.1 to v0.2 : we must change account reference by making a +1 to its index references
+static void homebank_ugrade_v01_to_v02(void)
+{
+GList *list;
+	
+	list = g_list_first(GLOBALS->ope_list);
+	while (list != NULL)
+	{
+	Operation *entry = list->data;
+		entry->account++;
+		entry->dst_account++;
+		list = g_list_next(list);
+	}
+
+	list = g_list_first(GLOBALS->arc_list);
+	while (list != NULL)
+	{
+	Archive *entry = list->data;
+		entry->account++;
+		entry->dst_account++;
+		list = g_list_next(list);
+	}
+}
+
+// v0.2 to v0.3 : we must assume categories exists : bugs 303886, 303738
+static void homebank_ugrade_v02_to_v03(void)
+{
+Category *cat;
+GList *list;
+
+	list = g_list_first(GLOBALS->ope_list);
+	while (list != NULL)
+	{
+	Operation *entry = list->data;
+
+		cat = da_cat_get(entry->category);
+		if(cat == NULL)
+		{
+			DB( g_print(" !! fixing cat for ope: %d is unknow\n", entry->category) );
+			entry->category = 0;
+		}
+
+		list = g_list_next(list);
+	}
+
+	list = g_list_first(GLOBALS->arc_list);
+	while (list != NULL)
+	{
+	Archive *entry = list->data;
+
+		cat = da_cat_get(entry->category);
+		if(cat == NULL)
+		{
+			DB( g_print(" !! fixing cat for arc: %d is unknow\n", entry->category) );
+			entry->category = 0;
+		}
+
+		list = g_list_next(list);
+	}
+}
+
+
+// v0.4 to v0.5 : 
+// we must assume dst_account exists in archives for internal xfer : bug 528923
+// if not, remove automation from the archive
+static void homebank_ugrade_v04_to_v05(void)
+{
+Account *acc;
+GList *list;
+
+	list = g_list_first(GLOBALS->arc_list);
+	while (list != NULL)
+	{
+	Archive *entry = list->data;
+
+		if(entry->paymode == PAYMODE_INTXFER)
+		{
+			acc = da_acc_get(entry->dst_account);
+			if(acc == NULL)
+			{
+				entry->flags &= ~OF_AUTO;
+			}
+		}
+		list = g_list_next(list);
+	}
+}
+
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
 /*
 ** XML properties save
 */
-static void homebank_prop_save_xml(GIOChannel *io)
+static void homebank_save_xml_prop(GIOChannel *io)
 {
 gchar *tmpstr;
 gchar *title;
@@ -551,7 +596,7 @@ gchar *title;
 /*
 ** XML account save
 */
-static void homebank_acc_save_xml(GIOChannel *io)
+static void homebank_save_xml_acc(GIOChannel *io)
 {
 GList *list;
 char buf1[G_ASCII_DTOSTR_BUF_SIZE];
@@ -596,7 +641,7 @@ gchar *tmpstr;
 /*
 ** XML payee save
 */
-static void homebank_pay_save_xml(GIOChannel *io)
+static void homebank_save_xml_pay(GIOChannel *io)
 {
 GList *list;
 gchar *tmpstr;
@@ -625,7 +670,7 @@ gchar *tmpstr;
 /*
 ** XML category save
 */
-static void homebank_cat_save_xml(GIOChannel *io)
+static void homebank_save_xml_cat(GIOChannel *io)
 {
 GList *list;
 guint i;
@@ -669,7 +714,7 @@ gchar *tmpstr;
 /*
 ** XML tag save
 */
-static void homebank_tag_save_xml(GIOChannel *io)
+static void homebank_save_xml_tag(GIOChannel *io)
 {
 GList *list;
 gchar *tmpstr;
@@ -699,7 +744,7 @@ gchar *tmpstr;
 /*
 ** XML assign save
 */
-static void homebank_asg_save_xml(GIOChannel *io)
+static void homebank_save_xml_asg(GIOChannel *io)
 {
 GList *list;
 gchar *tmpstr;
@@ -728,7 +773,7 @@ gchar *tmpstr;
 /*
 ** XML archive save
 */
-static void homebank_arc_save_xml(GIOChannel *io)
+static void homebank_save_xml_arc(GIOChannel *io)
 {
 GList *list;
 char buf[G_ASCII_DTOSTR_BUF_SIZE];
@@ -776,7 +821,7 @@ gchar *tmpstr;
 /*
 ** XML operation save
 */
-static void homebank_ope_save_xml(GIOChannel *io)
+static void homebank_save_xml_ope(GIOChannel *io)
 {
 GList *list;
 char buf[G_ASCII_DTOSTR_BUF_SIZE];
@@ -839,14 +884,14 @@ gchar *outstr;
 		g_io_channel_write_chars(io, outstr, -1, NULL, NULL);
 		g_free(outstr);
 
-		homebank_prop_save_xml(io);
-		homebank_acc_save_xml(io);
-		homebank_pay_save_xml(io);
-		homebank_cat_save_xml(io);
-		homebank_tag_save_xml(io);
-		homebank_asg_save_xml(io);
-		homebank_arc_save_xml(io);
-		homebank_ope_save_xml(io);
+		homebank_save_xml_prop(io);
+		homebank_save_xml_acc(io);
+		homebank_save_xml_pay(io);
+		homebank_save_xml_cat(io);
+		homebank_save_xml_tag(io);
+		homebank_save_xml_asg(io);
+		homebank_save_xml_arc(io);
+		homebank_save_xml_ope(io);
 
 		g_io_channel_write_chars(io, "</homebank>\n", -1, NULL, NULL);
 
